@@ -15,13 +15,14 @@ QMainWindow(parent, Qt::FramelessWindowHint),
     ui->switchButton->setAttribute(Qt::WA_TranslucentBackground);
     palette.setColor(QPalette::Base, Qt::transparent);
     ui->centralWidget->setPalette(palette);
-    ui->switchButton->setStyleSheet("background-color: grey; \
+    ui->switchButton->setStyleSheet("background-color: rgba(0, 0, 0, 50%); \
      border-style: outset; \
-     border-width: 2px; \
+     border-width: 0px; \
      border-radius: 10px; \
-     border-color: grey; \
+     border-color: rgba(0, 0, 0, 50%); \
      font: bold 14px; \
-     min-width: 10em; \
+     min-width: 48px; \
+     width: 48px; \
      padding: 6px;");
     QSettings settings;
     if (!settings.contains("profilechangerwidget/width"))
